% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/icomplex.R
\name{QRcomp}
\alias{QRcomp}
\title{QR factorization without pivoting}
\source{
LAPACK routine ZGEQRF is used for the QR factorization without pivoting.
}
\usage{
QRcomp(A, complete = FALSE)
}
\arguments{
\item{A}{a complex matrix whose QR decomposition is to be computed.}

\item{complete}{boolean that indicates if the R matrix should be completed with 0s
to its full rank.}
}
\value{
Returns a list with the following components:
 \item{qr}{a matrix with the same dimensions as A. The upper triangle contains
 the \bold{R} of the decomposition and the lower triangle contains information
 on the \bold{Q} of the decomposition (stored in compact form).}
 \item{qraux}{a vector of length ncol(A) which contains additional
 information on \bold{Q}.}
 \item{Q}{an orthogonal matrix such that Q*R is the input matrix.}
 \item{R}{an upper triangular matrix such that Q*R is the input matrix.}
}
\description{
This function performs QR factorization without pivoting to a complex matrix A.
}
\details{
This method is an alternative to the default qr function of base R.
The default function returns a pivoted solution in many cases, which is
not always the desired solution. In this function, we returned the unpivoted
solution for the QR factorization using the LAPACK routine ZGEQRF. This function
works with real and complex matrices.
}
\examples{

set.seed(2)
A<-matrix(c(complex(real=1,imaginary = 1),
complex(real=3,imaginary = -2), complex(real=2,imaginary = 1),
complex(real=0,imaginary = 3)),2,2)
qres<-QRcomp(A)

#Inspect the main results of the factorization:
qres$Q
qres$R

}
\references{
Anderson. E. and ten others (1999) LAPACK Users' Guide. Third Edition. SIAM.
Available on-line at http://www.netlib.org/lapack/lug/lapack_lug.html.
}
\keyword{QR}
\keyword{factorization}
